<?xml version="1.0" encoding="UTF-8"?>

<#--  Import common macros and functions  -->
<#import "macros_common_general.ftl" as com>
<#import "macros_common_studies_and_summaries.ftl" as studyandsummaryCom>
<#import "macros_NoS.ftl" as nos>
<#import "common_module_front_page_docbook.ftl" as fp>

<#--  Initialize common variables  -->
<@com.initializeMainVariables />

<#--  Get current date and time  -->
<#assign locale = "en" />
<#assign sysDateTime = .now>

<#-- Root entity -->
<#assign rootEntity = entity.root>

<#--  List of IUCLID's composite entity types  -->
<#assign compositeEntityTypes = ["SUBSTANCE", "MIXTURE", "TEMPLATE"] />

<#--  Create report only for dossiers  -->
<#if _dossierHeader?has_content>
    <#-- Initialize hashes to store NoS id information (input to table) -->
    <#assign NoSstudyHash = {} />
    <#assign missingNoSstudyHash = {} />

    <#-- Get path for nos information in dossier header depeding on context -->
    <#assign nosinfo = nos.getNosInfo(_dossierHeader)/>

    <#--  Docbook output  -->
    <book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">
        <#--  Print front page  -->
        <@fp.getFrontPage _subject _dossierHeader "Notification of Studies (NoS) Extraction Request" "" "NoS report"/>

        <#--  Chapters  -->
        <chapter>
            <#--  Initiate traversal approach  -->
            <#list dossier.components as component>
                <@traverseComponent component />
            </#list>

            <title role="HEAD-4">General details of the application</title>

            <@dossierHeaderInfo _dossierHeader />
        </chapter>

        <chapter xml:id="justNoSlist">
            <title>List of justified studies in the application</title>

            <para>
				The following table lists Notification of Studies (NoS) IDs that have been notified in the database 
                but are not included in this dossier or for which a justification has been provided. <?linebreak?>
                A justification for non inclusion or for any procedural deviations from the NoS obligations is provided 
                next to each NoS ID. <?linebreak?>
                This information is retrieved from the <emphasis role='bold'>dossier header</emphasis> and from the document 
                <emphasis role='bold'>‘Additional Transparency Regulation Information’</emphasis>.
			</para>

            <@justifiedStudiesTable nosinfo />
        </chapter>

        <chapter xml:id="NoSlist">
            <title>List of notified studies in the application</title>

        	<para>
				The following table lists all studies for which a NoS ID has been provided in the corresponding <emphasis role='bold'>literature reference</emphasis>
				(under <emphasis>Other study identifier(s)</emphasis> of <emphasis>Study ID Type</emphasis> = "Notification of Studies (NoS) ID").
			</para>

            <para role="small">
                <@studyTable NoSstudyHash "" "notified" />
            </para>
        </chapter>

        <chapter xml:id="noNoSlist">
            <title>List of studies without notification in the application</title>

			<para>
				The following table lists all <emphasis role='bold'>study reports</emphasis> performed <emphasis role='bold'>in or later than 2021</emphasis> for
				which a NoS ID <emphasis role='underline'>has not</emphasis> been provided in the corresponding <emphasis role='bold'>literature reference</emphasis>
				(under <emphasis>Other study identifier(s)</emphasis> of <emphasis>Study ID Type</emphasis> = "Notification of Studies (NoS) ID").
				<?linebreak?>The remarks of each study should provide a justification for the lack of notification.
			</para>

            <para role="small">
                <@studyTable missingNoSstudyHash "" "not notified" />
            </para>
        </chapter>
    </book>
</#if>


<#-- 
    The isCompositeEntityDocument function checks if a component is a composite entity and, 
    if so, returns true.

    Inputs:
    - component: ENTITY to be checked
-->
<#function isCompositeEntityDocument component>
    <#return compositeEntityTypes?seq_contains(component.documentType) />
</#function>


<#-- 
    The traverseComponent macro checks if a component is either a simple or composite 
    entity (SUBSTANCE, MIXTURE, or TEMPLATE) and calls the corresponding macro to traverse 
    the entity.

    Inputs:
    - component: ENTITY to be traversed
-->
<#macro traverseComponent component>
    <#if isCompositeEntityDocument(component)>
        <@traverseCompositeEntity component />
    <#else>
        <@traverseSimpleEntity component />
    </#if>
</#macro>


<#-- 
    The traverseSimpleEntity macro iterates through the documents of a component and 
    triggers directly the getLitRefsFromNode macro on a simple entity.

     Inputs:
     - component: ENTITY to be traversed
-->
<#macro traverseSimpleEntity component>
    <#list component.documents as document>​
        <@getLitRefsFromNode component document />
    </#list>
</#macro>


<#-- 
    The traverseCompositeEntity macro retrieves the table of contents of a composite 
    entity, iterates through its documents and triggers the getLitRefsFromNode macro.

    Inputs:
    - component: ENTITY to be traversed
-->
<#macro traverseCompositeEntity component>
    <#--  Get table of contents  -->
    <#local toc = iuclid.localizeTreeFor(component.documentType, component.submissionType, component.documentKey, getInheritedTemplates(component), getRelatedCategories(component), getRelatedMixtures(component)) />
    
    <#if component?has_content>
        <#list component.documents as document>
            <#--  Get node for the table of contents  -->
            <#assign tocNode = toc.nodeFor["${document.documentType}.${document.documentSubType}"] />
                                    
            <#if document?has_content>
                <@getLitRefsFromNode component document tocNode />
            </#if>
        </#list>
    </#if>
</#macro>


<#--
    The getLitRefsFromNode function retrieves all the literature references from a given document.

    Arguments:
    - component: ENTITY to be traversed
    - node: CURRENT NODE being processed
    - tocNode: NODE for the table of contents

    The function performs the following steps:
    1. Check if the "node" is of type "document_reference". If so, it's a direct reference to a document.
       - If the referenced document exists and is of type "LITERATURE", get parent document, NoSIDs and 
       section and append this info to either NoSstudyHash or missingNoSstudyHash.
    2. Check if the "node" is of type "document_references". If so, it's a list of document references.
       - Iterate through the list of references, and for each referenced document:
         - If the referenced document exists and is of type "LITERATURE", get parent document, NoSIDs and 
       section and append this info to either NoSstudyHash or missingNoSstudyHash.
    3. If the "node" has child sections (subsections), recursively call the function on each child section.
-->
<#macro getLitRefsFromNode component node tocNode="">
    <#--  Check if node is a document reference  -->
    <#if node?node_type == "document_reference">
        <#--  Get referenced document  -->
        <#local refDoc = iuclid.getDocumentForKey(node) />

        <#--  Check if the referenced document has content and is of type "LITERATURE"  -->
        <#if refDoc?has_content && refDoc.documentType == "LITERATURE">
            <@appendNoSStudyToHash node tocNode refDoc />
        </#if>
    </#if>

    <#--  Check if the document is a list of document references  -->
    <#if node?node_type == "document_references">
        <#--  Iterate through list of references  -->
        <#list node as item>
            <#--  Get referenced document  -->
            <#local refDoc = iuclid.getDocumentForKey(item) />

            <#--  Check if the referenced document has content and is of type "LITERATURE"  -->
            <#if refDoc?has_content && refDoc.documentType == "LITERATURE">
                <#--  Append NoS study to hash  -->
                <@appendNoSStudyToHash node tocNode refDoc />
            </#if>
        </#list>
    </#if>

    <#--  Check if document has child sections (subsections)  -->
    <#if node?children?has_content>
        <#--  Iterate through child sections  -->
        <#list node?children as child>
            <#--  Recursively call the function on each child section to retrieve literature references  -->
            <@getLitRefsFromNode component child tocNode />
        </#list>
    </#if>
</#macro>


<#--
    The getParentDocFromNode function retrieves the parent document from a given node.

    Arguments:
    - node: NODE for which to find the parent document.
-->
<#function getParentDocFromNode node>
    <#--  Iterate through node's ancestors  -->
    <#list node?ancestors as ancestor>
        <#--  Check if ancestor's node type is "document"  -->
        <#if ancestor?node_type == "document">
            <#--  Get parent document  -->
            <#return ancestor />
        </#if>
    </#list>
</#function>


<#--
    The getSectionFromNode function retrieves the section title from a given table of contents node.

    Arguments:
    - node: Table of Contents NODE from which to generate the section title.
-->
<#function getSectionFromNode tocNode>
    <#local sect = "" />

    <#if tocNode?has_content>
        <#if tocNode.number?has_content>
            <#local sect = tocNode.number + " ">
        </#if>

        <#local sect = sect + tocNode.title>
    </#if>

    <#return sect />
</#function>


<#--  
    The appendNoSStudyToHash macro appends NoS study information to two different hashes based on the 
    presence of a NoS ID in the reference document.

    Inputs:
    - node: NODE from which to get the parent document.
    - tocNode: Table of Contents (TOC) NODE from which to get the section title.
    - refDoc: REFERENCED DOCUMENT from which to extract NoS IDs info from.
-->
<#macro appendNoSStudyToHash node tocNode refDoc>
    <#--  Get parent document from node  -->
    <#local parentDoc = getParentDocFromNode(node) />
    
    <#--  Get section  -->
    <#local sect = getSectionFromNode(tocNode) />

    <#--  Look for NoSIDs in reference document  -->
    <#local NoSid = nos.getNoSid(refDoc) />

    <#--  If NoS ID exists, append data to NoSstudyHash  -->
    <#if NoSid?has_content>
        <#assign NoSstudyHash = nos.addNosStudyAsUnique(refDoc, parentDoc, sect, NoSstudyHash) />
    <#--  
        If it does not exist, then append the study to the list without NoS ID if:
            - type is study report
            - year >= 2021 (or empty)
    -->
    <#else>
        <#--  Get reference type  -->
        <#local refType><@com.picklist refDoc.GeneralInfo.LiteratureType /></#local>

        <#--  Get reference year  -->
        <#local refYear = nos.getRefYear(refDoc) />

        <#--  Append data to missingNoSstudyHash -->
        <#if refType == "study report" && ((!refYear?has_content) || refYear >= 2021)>
            <#assign missingNoSstudyHash = nos.addNosStudyAsUnique(refDoc, parentDoc, sect, missingNoSstudyHash) />
        </#if>
    </#if>
</#macro>


<#-- 
    The dossierHeaderInfo macro prints information related to the dossier application, extracted from 
    the dossier header, as well as details on the subject (mixture, substance) and numbers of justified, 
    notified and not notified studies.

    Inputs:
    - dossier: _dossierHeader variable, obtained by the default initializeMainVariables macro.
-->
<#macro dossierHeaderInfo dossier>
    <#compress>
        <#--  Get context and paths  -->
        <#if dossier.documentSubType == "EU_PPP_MAXIMUM_RESIDUE_LEVELS">
            <#local app = dossier.MRLApplication.DossierSpecificInformation />
            <#local nosinfo = dossier.NotificationOfStudies />
        <#elseif dossier.documentSubType=="EU_PPP_MICROORGANISMS_FOR_MIXTURES" || dossier.documentSubType=="EU_PPP_ACTIVE_SUBSTANCE_FOR_MIXTURES">
            <#local app = dossier.ActiveSubstanceApproval />
            <#local nosinfo = dossier.NotificationOfStudies />
        <#elseif dossier.documentSubType == "EU_PPP_BASIC_SUBSTANCE">
            <#local app = dossier.BasicSubstanceApproval />
            <#local nosinfo = dossier.PreApplicationInformation />
        <#elseif dossier.documentSubType == "EU_PPP_PESTICIDE_PRODUCT">
            <#local app = dossier.ApplicationForOrAmendmentToPlantProtectionProductAuthorisation />
            <#local nosinfo = "" />
            <#--NOTE: nosinfo would raise error if run with this context (not possible at moment)-->
            <#--NOTE: not considered for the moment. Fields:-->
            <#--ApplicationForOrAmendmentToPlantProtectionProductAuthorisation.ApplicationIsMadeThroughARepresentativeOfTheApplicant (picklist)-->
            <#--ApplicationForOrAmendmentToPlantProtectionProductAuthorisation.AuthorisationPreviouslyGrantedForPlantProtectionProduct (picklist)-->
            <#--ApplicationForOrAmendmentToPlantProtectionProductAuthorisation.ConclusionSOfTheMemberStateAssessingEquivalence (picklist)-->
        </#if>

        <#if app?? && nosinfo??>
            <#--  Dossier details  -->
            <para>
                <emphasis role="bold">Application dossier details:</emphasis>

                <para role="indent">
                    <itemizedlist>
                        <listitem>Dossier name: <@com.text dossier.name /></listitem>
                        <listitem>Dossier UUID: ${com.sanitizeUUID(dossier.subjectKey)}</listitem>
                        <listitem>Dossier submission remarks: <@com.text dossier.remarks /></listitem>
                        <listitem>Dossier creation date and time: <@com.text dossier.creationDate /></listitem>
                        <listitem>Submission type: <@com.text dossier.submissionType /></listitem>
                        <listitem>Submitting legal entity:
                            <#local submittingLegalEntity = iuclid.getDocumentForKey(dossier.submittingLegalEntityKey) />

                            <#if submittingLegalEntity?has_content>
                                <@com.text submittingLegalEntity.GeneralInfo.LegalEntityName />
                            </#if>
                        </listitem>
                        <#if ownerLegalEntity?has_content>
                            <listitem>Owner legal entity: <@com.text ownerLegalEntity.GeneralInfo.LegalEntityName /></listitem>
                        </#if>
                        <#if thirdParty?has_content>
                            <listitem>Third party: <@com.text thirdParty.GeneralInfo.LegalEntityName /></listitem>
                        </#if>
                    </itemizedlist>
                </para>
            </para>

            <#--  EU reference number  -->
            <para>
                <emphasis role="bold">European reference number:</emphasis>

                <#--  For mixtures  -->
                <#if app.hasElement("EuropeanReferenceNumber")>
                    <@com.text app.EuropeanReferenceNumber />
                <#--  For basic and MRL  -->
                <#elseif app.hasElement("EUReferenceNumber")>
                    <@com.text app.EUReferenceNumber />
                <#--  For authorisations  -->
                <#elseif app.hasElement("ReferenceNumber")>
                    <@com.text app.ReferenceNumber />
                </#if>
            </para>

            <#--  Purpose  -->
            <para>
                <emphasis role="bold">Purpose of the application:</emphasis>

                <#--  For basic -->
                <#if app.hasElement("ScopeApp")>
                    <@com.picklist app.ScopeApp />

                    <#if app.ApplicationPurpose?has_content>
                        - <@com.text app.ApplicationPurpose />
                    </#if>
                <#--  For mixtures  -->
                <#elseif app.hasElement("ApplicationPurpose")>
                    <@com.picklist app.ApplicationPurpose />
                <#--  MRL  -->
                <#elseif app.hasElement("Purpose")>
                    <@com.picklistMultiple app.Purpose />
                <#--  For authorisations  -->
                <#elseif app.hasElement("ReferenceNumber")>
                    <@com.text app.ReferenceNumber />
                </#if>
            </para>

            <#--  Joint application  -->
            <#local printJA = true />

            <#if app.hasElement("JointApplication")>
                <#local joint><@com.picklist app.JointApplication /></#local>

                <para>
                    <emphasis role="bold">Joint application:</emphasis>

                    <#if joint?has_content>${joint}
                        <#if joint?matches("^yes.*") && app.hasElement("EuJsNumber") && app.EuJsNumber?has_content>
                            <para role="indent">European joint submission number: <@com.text app.EuJsNumber /></para>

                            <#local printJA = false/>
                        </#if>
                    <#else>
                        NA
                    </#if>
                </para>
            </#if>

            <#if app.hasElement("EuJsNumber") && printJA && app.EuJsNumber?has_content>
                <para><emphasis role="bold">European joint submission number: </emphasis><@com.text app.EuJsNumber /></para>
            </#if>

            <#--  Lead applicant  -->
            <#if app.hasElement("LeadApplicant")>
                <para><emphasis role="bold">Lead applicant: </emphasis><@com.picklist app.LeadApplicant /></para>
            </#if>

            <#--  RMs/EMs  -->
            <#--  For mixtures  -->
            <#if app.hasElement("RapporteurMemberState")>
                <para><emphasis role="bold">Rapporteur Member State (RMS):</emphasis>
                    <@com.picklist app.RapporteurMemberState />

                    <#if app.hasElement("CompetentAuthority") && app.CompetentAuthority?has_content>
                        <para role="indent">- Competent Authority: <@com.text app.CompetentAuthority /></para>
                    </#if>

                    <#if app.hasElement("CoRms") && app.CoRms?has_content>
                        <para role="indent">- Co-RMS: <@com.picklistMultiple app.CoRms /></para>
                    </#if>
                </para>
            <#--  MRL  -->
            <#elseif app.hasElement("EMS")>
                <para><emphasis role="bold">Evaluating Member State (EMS):</emphasis>
                    <@com.picklist app.EMS />
                </para>
            <#--  Basic  -->
            <#elseif app.hasElement("Contributors")>
                <para><emphasis role="bold">Contributors:</emphasis>
                    <@com.text app.Contributors />
                </para>
            </#if>

            <#--  Only for MRL  -->
            <#if dossier.documentSubType == "EU_PPP_MAXIMUM_RESIDUE_LEVELS">
                <para><emphasis role="bold">Applicant:</emphasis><@com.picklistMultiple app.Applicant /></para>
                <para><emphasis role="bold">Data requirements:</emphasis><@com.picklist app.DataRequirements /></para>
            </#if>

            <#--  Other application linked (TO BE TESTED)  -->
            <#if dossier.hasElement("OtherSubmissionRelatedInformation")>
                <#if dossier.OtherSubmissionRelatedInformation.hasElement("PartOfMRLAppl") && dossier.OtherSubmissionRelatedInformation.PartOfMRLAppl>
                    <para><emphasis role="bold">MRL application dossier submitted:</emphasis>
                        yes
                        <#if dossier.OtherSubmissionRelatedInformation.SubmissionNumber?has_content>
                            - <@com.text dossier.OtherSubmissionRelatedInformation.SubmissionNumber />
                        </#if>
                    </para>
                <#elseif dossier.OtherSubmissionRelatedInformation.hasElement("PartOfActiveSubstanceAppl")&& dossier.OtherSubmissionRelatedInformation.PartOfActiveSubstanceAppl>
                    <para><emphasis role="bold">MRL application dossier submitted:</emphasis>
                        yes
                        <#if dossier.OtherSubmissionRelatedInformation.SubmissionNumber?has_content>
                            - <@com.text dossier.OtherSubmissionRelatedInformation.SubmissionNumber />
                        </#if>
                    </para>
                </#if>
            </#if>

            <#--  Subject  -->
            <para><emphasis role="bold">Subject of the application:</emphasis>
                <#if _subject.documentType == "MIXTURE">
                    <#assign otherProd = com.getOtherRepresentativeProducts(_subject) />
                    <#assign products = [_subject] + otherProd />

                    <#list products as prod>
                        <@com.emptyLine/>
                        <para role="indent"><emphasis role="underline">Representative Product<#if (products?size > 1)> #${prod?index + 1}</#if>:</emphasis>  <@mixtureIdentity prod /></para>
                    </#list>
                    <@com.emptyLine/>
                    <#local actSubs = com.getComponents(_subject, "active substance", false) />
                    <#if actSubs?has_content>
                        <#local actSub = actSubs[0] />

                        <para role="indent"><emphasis role="underline">Active substance:</emphasis>
                            <@substanceIdentity actSub />
                        </para>
                        <@com.emptyLine/>
                    </#if>

                <#elseif _subject.documentType == "SUBSTANCE">
                    <para role="indent"><@substanceIdentity actSub /></para>
                </#if>
            </para>

            <#--  Preapp ID  -->
            <para><emphasis role="bold">Pre-application identification:</emphasis>
                <#if nosinfo?has_content && nosinfo.PreApplicationId?has_content>
                    <#list nosinfo.PreApplicationId as paid>
                        <@com.text paid.PreApplicationId />
                        <#if paid_has_next>; </#if>
                    </#list>
                <#else>
                    NA
                </#if>
            </para>

            <#--  NoSID justification  -->
            <para>
                <command linkend="justNoSlist"><emphasis role="bold">Studies requiring NoS justification:</emphasis></command>
                <#if nosinfo?has_content>
                    ${nosinfo.StudiesReqJustification?size}
                <#else>
                    0
                </#if>
            </para>

            <#-- NoS ids-->
            <para>
                <command linkend="NoSlist"><emphasis role="bold">Studies with NoS identification:</emphasis></command> ${NoSstudyHash?keys?size}
            </para>

            <#-- missing NoS ids-->
            <para>
                <command linkend="noNoSlist"><emphasis role="bold">Studies lacking NoS identification:</emphasis></command> ${missingNoSstudyHash?keys?size}
            </para>
        </#if>
    </#compress>
</#macro>


<#--
    The justifiedStudiesTable prints information relating to justified studies as present in the dossier 
    header.

    Inputs:
    - nosinfo: PATH to section containing NoS information in the dossier header. The path depends on the 
    context (e.g. dossier.NotificationOfStudies).
    
-->
<#macro justifiedStudiesTable nosinfo>
    <#compress>
        <#--  Create table  -->
        <table border="1">
            <#--  Set columns width  -->
            <col width="3%" />
            <col width="15%" />
            <col width="72%" />
            <col width="10%" />

            <#--  Define table body  -->
            <tbody>
                <#--  Header  -->
                <tr>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">#</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">NoS ID</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Justification</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Confidential</emphasis></th>
                </tr>

                <#local rowNum = 0>

                <#if nosinfo?has_content && nosinfo.StudiesReqJustification?has_content>
                    <#list nosinfo.StudiesReqJustification as nos>
                        <#local rowNum++>

                        <#--  Body  -->
                        <tr>
                            <#--  #  -->
                            <td>${rowNum}</td>

                            <#--  NoS ID  -->
                            <td>
                                <#local nosID>
                                    <#if nos.hasElement("NosId")>
                                        <@com.text nos.NosId />
                                    <#elseif nos.hasElement("NoSID")>
                                        <@com.text nos.NoSID />
                                    <#--basic-->
                                    <#elseif nos.hasElement("EFSAStudyIdentification")>
                                        <@com.text nos.EFSAStudyIdentification />
                                    </#if>
                                </#local>

                                ${nosID}
                            </td>

                            <#--  Justification  -->
                            <td><@com.text nos.Justification /></td>

                            <#--  Confidential  -->
                            <td>No</td>
                        </tr>
                    </#list>
                </#if>

                <#local addTranspRegInfo = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FIXED_RECORD", "AddTranspRegInfo") />

                <#if addTranspRegInfo?has_content>
                    <#list addTranspRegInfo as summary>
                        <#if summary.ConfidentialityAssessment?has_content>
                            <#if summary.ConfidentialityAssessment.StudiesRequiringConfidentialNoSJustification.ConfNoSJustif?has_content>
                                <#list summary.ConfidentialityAssessment.StudiesRequiringConfidentialNoSJustification.ConfNoSJustif as row>
                                    <#local rowNum++>

                                    <tr>
                                        <#--  #  -->
                                        <td>${rowNum}</td>

                                        <#--  NoS ID  -->
                                        <td><@com.text row.NoSID /></td>

                                        <#--  Justification  -->
                                        <td><@com.text row.ConfidentialJustification /></td>

                                        <#--  Confidential  -->
                                        <td>Yes</td>
                                    </tr>
                                </#list>
                            </#if>
                        </#if>
                    </#list>
                </#if>
            </tbody>
        </table>
    </#compress>
</#macro>


<#--
    The studyTable prints a table containing a list of studies, either notified or lacking notification, and
    some details about them.

    Inputs:
    - studyHash: HASH obtained using function addNosStudyAsUnique.
    - title: TABLE title.
    - type: "notified" for list of NoS studies, and "not notified" for table of studies lacking NoS notification.
-->
<#macro studyTable studyHash title="" type="notified">
    <#compress>
        <#--  Create table  -->
        <table border="1">
            <#--  Set title  -->
            <title>${title}</title>

            <#--  Set columns width  -->
            <col width="3%" />
            <col width="14%" />
            <col width="15%" />
            <col width="8%" />
            <col width="8%" />
            <col width="8%" />
            <col width="8%" />
            <col width="12%" />
            <col width="11%" />
            <col width="6%" />
            <col width="7%" />

            <#--  Define table content  -->
            <tbody>
                <tr>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">#</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">NoS ID / remarks</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Study name</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Testing facility</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Start date</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">End date</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Study period remark</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Section and endpoint</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Guideline</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">GLP</emphasis></th>
                    <th><?dbfo bgcolor="#d3d3d3" ?><emphasis role="bold">Adequacy</emphasis></th>
                </tr>

                <#list studyHash as key, value>
                    <#local reference = value['reference'] />
                    <#local studies = value['doc'] />
                    <#local sections = value['section'] />

                    <#local usespan = true />

                    <#list studies as study>
                        <tr>
                            <#if usespan>
                                <#--  #  -->
                                <td rowspan="${studies?size}">
                                    ${key_index+1}
                                </td>

                                <#--  NoS ID and remarks  -->
                                <td rowspan="${studies?size}">
                                    <#local NosRemarks = nos.getNoSidRemarks(reference) />

                                    <#if type == "notified">
                                        <#local NoSid = nos.getNoSid(reference, true) />

                                        ${NoSid}<#if NosRemarks?has_content><?linebreak?>(${NosRemarks})</#if>
                                    <#elseif type == "not notified">
                                        <#local NoSid = nos.getNoSid(reference, false) />
                                        <#if NoSid?has_content>${NoSid}: </#if>${NosRemarks}
                                    </#if>
                                </td>

                                <#--  Study name / reference (author, year, No)  -->
                                <#local refUrl = iuclid.webUrl.documentView(reference.documentKey) />

                                <td rowspan="${studies?size}">
                                    <ulink url="${refUrl}"><@com.text reference.GeneralInfo.Name/></ulink><?linebreak?>

                                    (<@com.text reference.GeneralInfo.Author />, <@com.number reference.GeneralInfo.ReferenceYear />, No: <@com.text reference.GeneralInfo.ReportNo />)
                                </td>

                                <#--  Testing facility  -->
                                <td rowspan="${studies?size}"><@com.text reference.GeneralInfo.TestLab /></td>

                                <#local usespan = false />
                            </#if>

                            <#--  Start date  -->
                            <td><#if study.hasElement("AdministrativeData.StudyPeriodStartDate")><@com.value study.AdministrativeData.StudyPeriodStartDate /></#if></td>

                            <#--  End date  -->
                            <td><#if study.hasElement("AdministrativeData.StudyPeriodEndDate")><@com.value study.AdministrativeData.StudyPeriodEndDate /></#if></td>

                            <#--  Study period remark  -->
                            <td><#if study.hasElement("AdministrativeData.StudyPeriod")><@com.text study.AdministrativeData.StudyPeriod /></#if></td>

                            <#--  Section and endpoint  -->
                            <#local section = sections[study?index] />

                            <#local stUrl = iuclid.webUrl.documentView(study.documentKey) />

                            <#local endpoint>
                                <#compress>
                                    <#if study.hasElement("AdministrativeData.Endpoint")>
                                        <@com.picklist study.AdministrativeData.Endpoint />
                                    <#else>
                                        <#if study.documentSubType=="IntermediateEffects">
                                            intermediate effects: <@com.picklist study.AdministrativeData.StudyResultType />
                                        <#elseif study.documentSubType == "AnalyticalProfileOfBatches">
                                            5-batch analysis
                                        <#elseif study.documentSubType=="BioPropertiesMicro">
                                            biological properties of the microorganism
                                        </#if>
                                    </#if>
                                </#compress>
                            </#local>

                            <td>
                                <ulink url="${stUrl}">
                                    <@com.text section /><#if endpoint?has_content>:<?linebreak?>${endpoint}</#if>
                                </ulink>
                            </td>

                            <#--  Guideline  -->
                            <td>
                                <#if study.hasElement("MaterialsAndMethods.Guideline")>
                                    <@studyandsummaryCom.guidelineList study.MaterialsAndMethods.Guideline/>
                                <#elseif study.hasElement("MaterialsAndMethods.MethodUsed")>
                                    <#if study.hasElement("MaterialsAndMethods.MethodUsed.Qualifier")>
                                        <@com.picklist study.MaterialsAndMethods.MethodUsed.Qualifier />
                                    </#if>
                                    <#if study.hasElement("MaterialsAndMethods.MethodUsed.MethodUsed")>
                                        method <@com.picklist study.MaterialsAndMethods.MethodUsed.MethodUsed />
                                    </#if>
                                <#else>
                                    ----
                                </#if>
                            </td>

                            <#--  GLP  -->
                            <td>
                                <#if study.hasElement("MaterialsAndMethods")>
                                    <#if study.hasElement("MaterialsAndMethods.GLPComplianceStatement")>
                                        <@com.picklist study.MaterialsAndMethods.GLPComplianceStatement />
                                    <#elseif study.hasElement("MaterialsAndMethods.MethodUsed.GLPCompliance")>
                                        <@com.picklist study.MaterialsAndMethods.MethodUsed.GLPCompliance />
                                    </#if>

                                    <#if study.hasElement("MaterialsAndMethods.OtherQualityAssurance") && study.MaterialsAndMethods.OtherQualityAssurance?has_content>
                                        <?linebreak?>other quality assurance: <@com.picklist study.MaterialsAndMethods.OtherQualityAssurance />
                                    <#elseif study.hasElement("MaterialsAndMethods.MethodUsed.OtherQualityFollowed") && study.MaterialsAndMethods.MethodUsed.OtherQualityFollowed?has_content>
                                        <?linebreak?>other quality assurance: <@com.picklist study.MaterialsAndMethods.MethodUsed.OtherQualityFollowed />
                                    </#if>
                                <#else>
                                    ----
                                </#if>
                            </td>

                            <#--  Adequacy  -->
                            <td>
                                <#if study.hasElement("AdministrativeData.PurposeFlag")><@com.picklist study.AdministrativeData.PurposeFlag /><#else>----</#if>
                            </td>
                        </tr>
                    </#list>
                </#list>
            </tbody>
        </table>
    </#compress>
</#macro>


<#--
    The mixtureIdentity prints general information about a mixture.

    Inputs:
    - mixture: MIXTURE entity.
-->
<#macro mixtureIdentity mixture>
    <#compress>
        <@com.text mixture.MixtureName />

        <#if mixture.PublicName?has_content>(<@com.text mixture.PublicName />)</#if>

        <#if mixture.OtherNames?has_content>
            <para role="indent2">
                <itemizedlist>
                    <#list mixture.OtherNames as name>
                        <listitem><@com.picklist name.NameType />: <@com.text name.Name />
                            <#if name.Country?has_content>
                                in <@com.picklistMultiple name.Country />
                            </#if>

                            <#if name.Remarks?has_content><@com.text name.Remarks /></#if>
                        </listitem>
                    </#list>
                </itemizedlist>
            </para>
        </#if>

        <#--  Compositions  -->
        <#local compositions = iuclid.getSectionDocumentsForParentKey(mixture.documentKey, "FLEXIBLE_RECORD", "MixtureComposition") />

        <#if compositions?has_content>
            <#list compositions as composition>
                <para role="indent2">
                    <emphasis role="underline">Composition<#if (compositions?size>1)> #${composition_index+1}</#if></emphasis>:
                    <@com.text composition.GeneralInformation.Name/>

                    <#if composition.GeneralInformation.TradeNames?has_content>
                        <para role="indent3">
                            - trade name(s):
                            <#list composition.GeneralInformation.TradeNames as tradeName>
                                <@com.text tradeName.TradeName/>
                                <#if tradeName.Country?has_content>
                                    (<@com.picklistMultiple tradeName.Country />)
                                </#if>
                                <#if tradeName_has_next>|</#if>
                            </#list>
                        </para>
                    </#if>
                </para>
            </#list>
        </#if>
    </#compress>
</#macro>


<#--
    The substanceIdentity prints general information about a substance.

    Inputs:
    - substance: SUBSTANCE entity.
-->
<#macro substanceIdentity substance>
    <#compress>
        <@com.text substance.ChemicalName />

        <#if substance.PublicName?has_content>(<@com.text substance.PublicName />)</#if>

        <#local referenceSubstance = iuclid.getDocumentForKey(substance.ReferenceSubstance.ReferenceSubstance) />

        <#if substance.OtherNames?has_content || referenceSubstance?has_content>
            <para role="indent2">
                <itemizedlist>
                    <#if substance.OtherNames?has_content>
                        <#list substance.OtherNames as name>
                            <listitem><@com.picklist name.NameType/>: <@com.text name.Name />
                                <#if name.Country?has_content>
                                    in <@com.picklistMultiple name.Country />
                                </#if>
                            </listitem>
                        </#list>
                    </#if>

                    <#if referenceSubstance?has_content>
                        <listitem>Ref. substance: <@com.text referenceSubstance.ReferenceSubstanceName /></listitem>
                        <#if referenceSubstance.Inventory?? && referenceSubstance.Inventory.InventoryEntry?has_content>
                            <listitem>EC number : <@com.inventoryECNumber com.getReferenceSubstanceKey(substance.ReferenceSubstance.ReferenceSubstance) /></listitem>
                        </#if>
                        <#if referenceSubstance.Inventory?? && referenceSubstance.Inventory.InventoryEntry?has_content>
                            <listitem>EC name: <@com.inventoryECName com.getReferenceSubstanceKey(substance.ReferenceSubstance.ReferenceSubstance) /></listitem>
                        </#if>
                        <#if referenceSubstance.Inventory?? && referenceSubstance.Inventory.InventoryEntry?has_content>
                            <listitem>CAS number (EC inventory): <@com.inventoryECCasNumber com.getReferenceSubstanceKey(substance.ReferenceSubstance.ReferenceSubstance) /></listitem>
                        </#if>
                        <#if referenceSubstance?? && referenceSubstance.Inventory.CASNumber?has_content>
                            <listitem>CAS number:<@com.casNumber com.getReferenceSubstanceKey(substance.ReferenceSubstance.ReferenceSubstance) /></listitem>
                        </#if>
                        <#if referenceSubstance?? && referenceSubstance.Inventory.CASName?has_content>
                            <listitem>CAS name: <@com.casName com.getReferenceSubstanceKey(substance.ReferenceSubstance.ReferenceSubstance) /></listitem>
                        </#if>
                        <#if referenceSubstance?? && referenceSubstance.IupacName?has_content>
                            <listitem>IUPAC name: <@com.iupacName com.getReferenceSubstanceKey(substance.ReferenceSubstance.ReferenceSubstance) /></listitem>
                        </#if>
                        <#if referenceSubstance?? && referenceSubstance.Synonyms.Synonyms?has_content>
                            <#local synonyms = nos.getSynonyms(referenceSubstance)?join(" | ") />

                            <#if synonyms?has_content>
                                <listitem>Synonyms: ${synonyms}</listitem>
                            </#if>
                        </#if>
                    </#if>
                </itemizedlist>
            </para>
        </#if>
    </#compress>
</#macro>


<#function getInheritedTemplates entityDoc>
<#--
<#if !(mode?has_content && mode == "PUBLISHING") && entityDoc.documentType == "SUBSTANCE">
  <#return entityDoc.inherited>
</#if>
-->
    <#return []>
</#function>


<#function getRelatedCategories entityDoc>
    <#if !(mode?has_content && mode == "PUBLISHING")>
        <#local params={"key": [entityDoc.documentKey]}>
        <#return iuclid.query("iuclid6.SubstanceRelatedCategories", params, 0, 100)>
    </#if>
    <#return []>
</#function>


<#function getRelatedMixtures entityDoc>
<#--
<#if !(mode?has_content && mode == "PUBLISHING")>
  <#local params={"key": [entityDoc.documentKey]}>
  <#return iuclid.query("iuclid6.SubstanceRelatedMixtures", params, 0, 100)>
</#if>
 -->
    <#return []>
</#function>